==> lhcsmapi-1.2.19.tar.gz: lhcsmapi-1.2.19/lhcsmapi/gui/metadata/SignalPreviewModule.py <==
from ipywidgets import Layout, Box, VBox, Button, Label, IntProgress, SelectMultiple
import functools

from ...dbsignal.post_mortem.PmDbRequest import PmDbRequest
from ...dbsignal.post_mortem.PmDbSignal import PmDbSignal
from ...dbsignal.cals import CalsDbSignal
from ...metadata.SignalMetadata import SignalMetadata


class SignalPreviewModule(object):
    def __init__(self, get_start_time=None, get_end_time=None, get_state=None, ldb=None):

        self.btn_sn = Button(description="Add Signal", layout=Layout(width='20%'))
        self.btn_sn.on_click(functools.partial(SignalPreviewModule.on_btn_sn_clicked, self=self))

        self.lbl_out = Label(value="")
        self.progress_search = IntProgress(value=0, min=0, step=1, bar_style='success',
                                           orientation='horizontal', layout=Layout(width='20%'))

        self.signal_list = []
        self.get_state = get_state
        self.get_start_time = get_start_time
        self.get_end_time = get_end_time
        self.ldb = ldb

        box_add = Box(children=[self.btn_sn, self.lbl_out, self.progress_search])

        # Overview of signals to be queried
        self.selmul_query = SelectMultiple(
            options=[' ' * 100],
            description='Query',
            layout=Layout(display="flex", flex_flow='column', width='100%', height='250px')
        )

        self.btn_rmv = Button(description="Remove Selected", layout=Layout(width='15%'))
        self.btn_rmv.on_click(functools.partial(SignalPreviewModule.on_btn_rmv_clicked, self=self))

        self.widget = VBox([box_add, self.selmul_query, self.btn_rmv])

    def get_widget(self):
        return self.widget

    def get_signal_list(self):
        return self.signal_list

    @staticmethod
    def on_btn_sn_clicked(b, self):
        self.add_signals()

    def add_signals(self):
        state = self.get_state()
        if len(state.cirname) > 0:
            start_time = self.get_start_time()
            end_time = self.get_end_time()

            signal_names_in = SignalMetadata.get_signal_name(state.cir, state.cirname, state.sys, state.db,
                                                             state.sig)
            signal_names_in = [signal_names_in] if type(signal_names_in) is str else signal_names_in

            if state.db == 'PM':
                # add pm queries
                pm_metadata = SignalMetadata.get_circuit_signal_database_metadata(state.cir, state.cirname[0],
                                                                                  state.sys, state.db)
                system = pm_metadata["system"]
                class_name = pm_metadata["className"]
                source = pm_metadata["source"]
                # find PM data
                source = SignalMetadata.update_pm_source_with_wildcard(source, state.cir, state.sys, state.sig,
                                                                       state.wildcard)
                signal_names = SignalMetadata.update_pm_signal_names_with_wildcard(signal_names_in, state.sys, state.sig,
                                                                                   state.wildcard)

                # SignalMetadata should always return a list
                source = source if type(source) is list else [source]

                self.lbl_out.value = 'Searching for PM events'
                self.progress_search.max = len(source)
                self.progress_search.description = f'0/{len(source)}'

                # PmDbRequest can search over periods of time larger than a day
                event_source_and_timestamp = []
                for i, src in enumerate(source):
                    self.lbl_out.value = f'Searching for PM entries, source: {src}'

                    event_source_and_timestamp = PmDbRequest.find_events_between_dates(start_time, end_time, class_name,
                                                                                       src, system)
                    self.progress_search.value = i + 1
                    self.progress_search.description = f'{i + 1}/{len(source)}'

                for source, timestamp in event_source_and_timestamp:
                    for signal_name in signal_names:
                        self.signal_list.append(
                            PmDbSignal().build_signal(system=system, className=class_name, source=source,
                                                      signal=signal_name, eventTime=timestamp))
                self.lbl_out.value = 'Completed search for PM events'

            elif state.db == 'CALS':
                signal_names = SignalMetadata.update_cals_signal_names_with_wildcard(signal_names_in, state.sys,
                                                                                     state.wildcard)
                for signal_name in signal_names:
                    self.signal_list.append(CalsDbSignal.buildSignal(signal=signal_name, t_start=start_time,
                                                                     t_end=end_time, ldb=self.ldb))
            else:
                raise KeyError(f"Database type {state.db} not present in {['PM', 'CALS']}.")

            # update the query list
            self.update_query_list()

    def update_query_list(self):
        self.query_list = []
        for sl in self.signal_list:
            self.query_list.append(str(sl))

        with self.selmul_query.hold_trait_notifications():
            self.selmul_query.options = self.query_list

    @staticmethod
    def on_btn_rmv_clicked(b, self):
        # Query all, update progress bar and list
        if len(self.signal_list) > 0:
            selected = list(self.selmul_query.index)
            selected.reverse()
            for i in selected:
                self.signal_list.pop(i)
            self.update_query_list()

==> lhcsmapi-1.3.229.tar.gz: lhcsmapi-1.3.229/lhcsmapi/gui/metadata/SignalPreviewModule.py <==
from ipywidgets import Layout, Box, VBox, Button, Label, IntProgress, SelectMultiple
import functools

from lhcsmapi.dbsignal.post_mortem.PmDbRequest import PmDbRequest
from lhcsmapi.dbsignal.post_mortem.PmDbSignal import PmDbSignal
from lhcsmapi.dbsignal.cals import CalsDbSignal
from lhcsmapi.metadata.SignalMetadata import SignalMetadata


class SignalPreviewModule(object):
    def __init__(self, get_start_time=None, get_end_time=None, get_state=None, ldb=None):

        self.btn_sn = Button(description="Add Signal", layout=Layout(width='20%'))
        self.btn_sn.on_click(functools.partial(SignalPreviewModule.on_btn_sn_clicked, self=self))

        self.lbl_out = Label(value="")
        self.progress_search = IntProgress(value=0, min=0, step=1, bar_style='success',
                                           orientation='horizontal', layout=Layout(width='20%'))

        self.signal_list = []
        self.get_state = get_state
        self.get_start_time = get_start_time
        self.get_end_time = get_end_time
        self.ldb = ldb

        box_add = Box(children=[self.btn_sn, self.lbl_out, self.progress_search])

        # Overview of signals to be queried
        self.selmul_query = SelectMultiple(
            options=[' ' * 100],
            description='Query',
            layout=Layout(display="flex", flex_flow='column', width='100%', height='250px')
        )

        self.btn_rmv = Button(description="Remove Selected", layout=Layout(width='15%'))
        self.btn_rmv.on_click(functools.partial(SignalPreviewModule.on_btn_rmv_clicked, self=self))

        self.widget = VBox([box_add, self.selmul_query, self.btn_rmv])

    def get_widget(self):
        return self.widget

    def get_signal_list(self):
        return self.signal_list

    @staticmethod
    def on_btn_sn_clicked(b, self):
        self.add_signals()

    def add_signals(self):
        state = self.get_state()
        if len(state.cirname) > 0:
            start_time = self.get_start_time()
            end_time = self.get_end_time()

            signal_names_in = SignalMetadata.get_signal_name(state.cir, state.cirname, state.sys, state.db,
                                                             state.sig)
            signal_names_in = [signal_names_in] if type(signal_names_in) is str else signal_names_in

            if state.db == 'PM':
                # add pm queries
                pm_metadata = SignalMetadata.get_circuit_signal_database_metadata(state.cir, state.cirname[0],
                                                                                  state.sys, state.db)
                system = pm_metadata["system"]
                class_name = pm_metadata["className"]
                source = pm_metadata["source"]
                # find PM data
                source = SignalMetadata.update_pm_source_with_wildcard(source, state.cir, state.sys, state.sig,
                                                                       state.wildcard)
                signal_names = SignalMetadata.update_pm_signal_names_with_wildcard(signal_names_in, state.sys, state.sig,
                                                                                   state.wildcard)

                # SignalMetadata should always return a list
                source = source if type(source) is list else [source]

                self.lbl_out.value = 'Searching for PM events'
                self.progress_search.max = len(source)
                self.progress_search.description = f'0/{len(source)}'

                # PmDbRequest can search over periods of time larger than a day
                event_source_and_timestamp = []
                for i, src in enumerate(source):
                    self.lbl_out.value = f'Searching for PM entries, source: {src}'

                    event_source_and_timestamp = PmDbRequest.find_events_between_dates(start_time, end_time, class_name,
                                                                                       src, system)
                    self.progress_search.value = i + 1
                    self.progress_search.description = f'{i + 1}/{len(source)}'

                for source, timestamp in event_source_and_timestamp:
                    for signal_name in signal_names:
                        self.signal_list.append(
                            PmDbSignal().build_signal(system=system, className=class_name, source=source,
                                                      signal=signal_name, eventTime=timestamp))
                self.lbl_out.value = 'Completed search for PM events'

            elif state.db == 'CALS':
                signal_names = SignalMetadata.update_cals_signal_names_with_wildcard(signal_names_in, state.sys,
                                                                                     state.wildcard)
                for signal_name in signal_names:
                    self.signal_list.append(CalsDbSignal.buildSignal(signal=signal_name, t_start=start_time,
                                                                     t_end=end_time, ldb=self.ldb))
            else:
                raise KeyError(f"Database type {state.db} not present in {['PM', 'CALS']}.")

            # update the query list
            self.update_query_list()

    def update_query_list(self):
        self.query_list = []
        for sl in self.signal_list:
            self.query_list.append(str(sl))

        with self.selmul_query.hold_trait_notifications():
            self.selmul_query.options = self.query_list

    @staticmethod
    def on_btn_rmv_clicked(b, self):
        # Query all, update progress bar and list
        if len(self.signal_list) > 0:
            selected = list(self.selmul_query.index)
            selected.reverse()
            for i in selected:
                self.signal_list.pop(i)
            self.update_query_list()
